cofe.extern package
===================

Submodules
----------

cofe.extern.ewald module
------------------------

.. automodule:: cofe.extern.ewald
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cofe.extern
   :members:
   :undoc-members:
   :show-inheritance:
